
dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Deze vleermuis moet wel heel sterk zijn.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("O ja.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Dat rode beest is een beetje vreemd.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Misschien, maar ik denk dat we het nog nodig zullen hebben.")


dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")
dialogStr("Het is te krap voor mij. Je zult het daar beneden in je eentje moeten regelen.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Die witte vis zit vreselijk in de weg.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("Vis? Ik dacht dat het een steen was.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Ik denk dat we de Graal ergens anders moeten vinden...")


dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")
dialogStr("Wees eens wat optimistischer. We lossen dit zo op.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Ik weet het niet zo zeker.")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("Kijk, je bent er.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("Wat is dat voor vreselijk kleuren-wisselend monster?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("Dit is afgrijselijk.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("Dit is een belediging voor Moeder Natuur.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("Dat is de flitsende hamerkop.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("Dat is de verschietende afgrijseling.")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("Dat is de politiekvis.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Deze vleermuis is een beetje vreemd.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Deze vleermuis is behoorlijk traag.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Dit is een opgezette vleermuis.")


dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")
dialogStr("Dat is een beeld van een vleermuis.")


dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")
dialogStr("Het is een stalagmiet in de vorm van een vleermuis.")


dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")
dialogStr("Het is gewoon een stalagmiet.")


dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")
dialogStr("Het is een volkomen normaal stuk rots.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that ‘monster’.")
dialogStr("Ik denk dat je dat monster nodig gaat hebben.")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that ‘abomination’.")
dialogStr("Ik denk dat je je afkeer van dat \"misbaksel\" zult moeten overwinnen.")

